==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/NetworkManagerPropertiesNetworkManagerScopesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.NetworkManagerPropertiesNetworkManagerScopesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Scope of Network Manager.
 * @property managementGroups List of management groups.
 * @property subscriptions List of subscriptions.
 */
public data class NetworkManagerPropertiesNetworkManagerScopesArgs(
    public val managementGroups: Output<List<String>>? = null,
    public val subscriptions: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.NetworkManagerPropertiesNetworkManagerScopesArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.NetworkManagerPropertiesNetworkManagerScopesArgs =
        com.pulumi.azurenative.network.inputs.NetworkManagerPropertiesNetworkManagerScopesArgs.builder()
            .managementGroups(managementGroups?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .subscriptions(subscriptions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [NetworkManagerPropertiesNetworkManagerScopesArgs].
 */
@PulumiTagMarker
public class NetworkManagerPropertiesNetworkManagerScopesArgsBuilder internal constructor() {
    private var managementGroups: Output<List<String>>? = null

    private var subscriptions: Output<List<String>>? = null

    /**
     * @param value List of management groups.
     */
    @JvmName("wbkbnkcrgwulawub")
    public suspend fun managementGroups(`value`: Output<List<String>>) {
        this.managementGroups = value
    }

    @JvmName("obutldsubtxlahlu")
    public suspend fun managementGroups(vararg values: Output<String>) {
        this.managementGroups = Output.all(values.asList())
    }

    /**
     * @param values List of management groups.
     */
    @JvmName("scphumjagmeabkai")
    public suspend fun managementGroups(values: List<Output<String>>) {
        this.managementGroups = Output.all(values)
    }

    /**
     * @param value List of subscriptions.
     */
    @JvmName("hpwrvthbipdakkkx")
    public suspend fun subscriptions(`value`: Output<List<String>>) {
        this.subscriptions = value
    }

    @JvmName("qsjnyjtaaxtwnuqe")
    public suspend fun subscriptions(vararg values: Output<String>) {
        this.subscriptions = Output.all(values.asList())
    }

    /**
     * @param values List of subscriptions.
     */
    @JvmName("wjsisthrqexsljgr")
    public suspend fun subscriptions(values: List<Output<String>>) {
        this.subscriptions = Output.all(values)
    }

    /**
     * @param value List of management groups.
     */
    @JvmName("heynflskjoddgqsm")
    public suspend fun managementGroups(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managementGroups = mapped
    }

    /**
     * @param values List of management groups.
     */
    @JvmName("xvwfklfwdnbqvogt")
    public suspend fun managementGroups(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.managementGroups = mapped
    }

    /**
     * @param value List of subscriptions.
     */
    @JvmName("futjkapqkmnhwxue")
    public suspend fun subscriptions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subscriptions = mapped
    }

    /**
     * @param values List of subscriptions.
     */
    @JvmName("tadgkkphtfdmcvtq")
    public suspend fun subscriptions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subscriptions = mapped
    }

    internal fun build(): NetworkManagerPropertiesNetworkManagerScopesArgs =
        NetworkManagerPropertiesNetworkManagerScopesArgs(
            managementGroups = managementGroups,
            subscriptions = subscriptions,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/NetworkManagerPropertiesNetworkManagerScopesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.NetworkManagerPropertiesNetworkManagerScopesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Scope of Network Manager.
 * @property managementGroups List of management groups.
 * @property subscriptions List of subscriptions.
 */
public data class NetworkManagerPropertiesNetworkManagerScopesArgs(
    public val managementGroups: Output<List<String>>? = null,
    public val subscriptions: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.NetworkManagerPropertiesNetworkManagerScopesArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.NetworkManagerPropertiesNetworkManagerScopesArgs =
        com.pulumi.azurenative.network.inputs.NetworkManagerPropertiesNetworkManagerScopesArgs.builder()
            .managementGroups(managementGroups?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .subscriptions(subscriptions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [NetworkManagerPropertiesNetworkManagerScopesArgs].
 */
@PulumiTagMarker
public class NetworkManagerPropertiesNetworkManagerScopesArgsBuilder internal constructor() {
    private var managementGroups: Output<List<String>>? = null

    private var subscriptions: Output<List<String>>? = null

    /**
     * @param value List of management groups.
     */
    @JvmName("ywdoiuxnhlmydnoq")
    public suspend fun managementGroups(`value`: Output<List<String>>) {
        this.managementGroups = value
    }

    @JvmName("raumgpbckemmtifj")
    public suspend fun managementGroups(vararg values: Output<String>) {
        this.managementGroups = Output.all(values.asList())
    }

    /**
     * @param values List of management groups.
     */
    @JvmName("yddayylcdypkpudd")
    public suspend fun managementGroups(values: List<Output<String>>) {
        this.managementGroups = Output.all(values)
    }

    /**
     * @param value List of subscriptions.
     */
    @JvmName("vhjxahhhrqqtrpvl")
    public suspend fun subscriptions(`value`: Output<List<String>>) {
        this.subscriptions = value
    }

    @JvmName("rvygctwyqxrvjkls")
    public suspend fun subscriptions(vararg values: Output<String>) {
        this.subscriptions = Output.all(values.asList())
    }

    /**
     * @param values List of subscriptions.
     */
    @JvmName("svnnmwjibvlavqnv")
    public suspend fun subscriptions(values: List<Output<String>>) {
        this.subscriptions = Output.all(values)
    }

    /**
     * @param value List of management groups.
     */
    @JvmName("rsleipttykaxlqin")
    public suspend fun managementGroups(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managementGroups = mapped
    }

    /**
     * @param values List of management groups.
     */
    @JvmName("kfrpvnchkwyvlwjc")
    public suspend fun managementGroups(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.managementGroups = mapped
    }

    /**
     * @param value List of subscriptions.
     */
    @JvmName("aeellyxhfafxgwsi")
    public suspend fun subscriptions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subscriptions = mapped
    }

    /**
     * @param values List of subscriptions.
     */
    @JvmName("mypqylsxhqdkfjmn")
    public suspend fun subscriptions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subscriptions = mapped
    }

    internal fun build(): NetworkManagerPropertiesNetworkManagerScopesArgs =
        NetworkManagerPropertiesNetworkManagerScopesArgs(
            managementGroups = managementGroups,
            subscriptions = subscriptions,
        )
}
